@@ -190,7 +190,7 @@ App::Pimpd::Collection
 
   Magnus Woldrich
   CPAN ID: WOLDRICH
-  magnus@trapd00r.se
+  m@japh.se
   http://japh.se
 
 =head1 COPYRIGHT
